# Libera Science Data Processing Utilities

Libera Utils is a package containing modules that
are commonly used throughout the Libera Science Data Center codebase and processing algorithms. This package is
published on PyPI to support our L2 algorithm developers with standardized code for interacting with our AWS resources
and a consistent API for common tasks required of all developers.

## Documentation

Documentation site, including full API listing: [https://lasp-libera-sdc-libera-utils.readthedocs-hosted.com](https://lasp-libera-sdc-libera-utils.readthedocs-hosted.com)

Additional documentation helpful for Level 2 Algorithm Developers is also available in the Libera SDC Developer Guide.
Please contact the Libera SDC Team at LASP for access to the Developer Guide.

## Installation

```bash
pip install libera-utils
```

Other suffixed versions such as release candidate versions
(version strings suffixed with `rc` followed by the candidate number, e.g. `1.2.3rc2`)
may also be available but are likely to contain bugs.
